"use client";

import { useState, useEffect } from "react";
import { useRouter } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useStudents } from "@/lib/hooks/useStudents";
import { useClasses } from "@/lib/hooks/useClasses";
import { useAttendance } from "@/lib/hooks/useAttendance";
import { useTeachers } from "@/lib/hooks/useTeachers";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { ChartContainer } from "@/components/dashboard/ChartContainer";
import {
  Card,
  CardContent,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { Button } from "@/components/ui/button";
import { Calendar } from "@/components/ui/calendar";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover";
import { CalendarIcon, Users, UserCheck, UserX, GraduationCap, ArchiveIcon } from "lucide-react";
import { format, subDays, startOfWeek, endOfWeek, subMonths, startOfMonth, endOfMonth } from "date-fns";
import { cn } from "@/lib/utils";

export default function ReportsPage() {
  const router = useRouter();
  const { user, loading: authLoading } = useAuth();
  const { students } = useStudents();
  const { classes } = useClasses();
  const { teachers } = useTeachers();
  const { getWeeklyAttendance, getAttendanceByClass } = useAttendance();
  
  const [selectedClass, setSelectedClass] = useState<string>("");
  const [selectedDate, setSelectedDate] = useState<Date>(new Date());
  const [attendanceData, setAttendanceData] = useState<any[]>([]);
  const [weeklyAttendanceData, setWeeklyAttendanceData] = useState<any[]>([]);
  const [monthlyAttendanceData, setMonthlyAttendanceData] = useState<any[]>([]);
  const [classDistribution, setClassDistribution] = useState<any[]>([]);
  const [isLoading, setIsLoading] = useState(false);
   const [isLoadingMonthly, setIsLoadingMonthly] = useState(false);

  // Redirect if not admin
  if (!authLoading && (!user || user.role !== "admin")) {
    router.push("/dashboard");
    return null;
  }

  // Set initial selected class
  useEffect(() => {
    if (classes.length > 0 && !selectedClass) {
      setSelectedClass(classes[0].id);
    }
  }, [classes, selectedClass]);

  // Fetch attendance data when class or date changes
  useEffect(() => {
    if (selectedClass && selectedDate) {
      fetchAttendanceData();
    }
  }, [selectedClass, selectedDate]);

  // Fetch attendance data when class or date changes
  useEffect(() => {
    if (selectedClass && selectedDate) {
      fetchAttendanceData();
    }
  }, [selectedClass, selectedDate]);

  // Fetch monthly attendance data when class changes
  useEffect(() => {
    if (selectedClass) {
      fetchMonthlyAttendanceData();
    }
  }, [selectedClass]);

  // Calculate class distribution
  useEffect(() => {
    const classStats = classes.map(cls => {
      const studentsInClass = students.filter(s => 
        s.classIds?.includes(cls.id)
      ).length;
      return {
        name: cls.name,
        value: studentsInClass
      };
    });

    setClassDistribution(classStats);
  }, [students, classes]);

  const fetchAttendanceData = async () => {
    if (!selectedClass || !selectedDate) return;

    setIsLoading(true);
    try {
      const dateStr = format(selectedDate, "yyyy-MM-dd");
      
      // Get attendance for specific date
      const dayAttendance = await getAttendanceByClass(selectedClass, dateStr, dateStr);
      
      // Count attendance status
      const presentCount = dayAttendance.filter(a => a.status === "present").length;
      const absentCount = dayAttendance.filter(a => a.status === "absent").length;
      const lateCount = dayAttendance.filter(a => a.status === "late").length;

      setAttendanceData([
        { name: "Present", value: presentCount },
        { name: "Absent", value: absentCount },
        { name: "Late", value: lateCount },
      ]);

      // Get weekly attendance data
      const weekStart = startOfWeek(selectedDate);
      const weekEnd = endOfWeek(selectedDate);
      
      const weeklyData = await getWeeklyAttendance(
        selectedClass, 
        format(weekStart, "yyyy-MM-dd"), 
        format(weekEnd, "yyyy-MM-dd")
      );

      const chartData = weeklyData.map(day => ({
        name: day.day.substring(0, 3),
        present: day.present,
        absent: day.absent,
        late: day.late
      }));

      setWeeklyAttendanceData(chartData);
    } catch (error) {
      console.error("Error fetching attendance data:", error);
    } finally {
      setIsLoading(false);
    }
  };

   const fetchMonthlyAttendanceData = async () => {
    if (!selectedClass) return;

    setIsLoadingMonthly(true);
    try {
      const monthlyData = [];
      const currentDate = new Date();

      // Get data for the last 6 months
      for (let i = 5; i >= 0; i--) {
        const monthDate = subMonths(currentDate, i);
        const monthStart = startOfMonth(monthDate);
        const monthEnd = endOfMonth(monthDate);
        
        const monthName = format(monthDate, "MMM yyyy");
        
        // Get attendance data for the entire month
        const attendanceRecords = await getWeeklyAttendance(
          selectedClass,
          format(monthStart, "yyyy-MM-dd"),
          format(monthEnd, "yyyy-MM-dd")
        );

        // Calculate totals for the month
        let totalPresent = 0;
        let totalAbsent = 0;
        let totalLate = 0;

        attendanceRecords.forEach(record => {
          totalPresent += record.present;
          totalAbsent += record.absent;
          totalLate += record.late;
        });

        // Calculate attendance rate (percentage of present students)
        const totalRecords = totalPresent + totalAbsent + totalLate;
        const attendanceRate = totalRecords > 0 ? Math.round((totalPresent / totalRecords) * 100) : 0;

        monthlyData.push({
          name: monthName,
          value: attendanceRate,
          present: totalPresent,
          absent: totalAbsent,
          late: totalLate,
          total: totalRecords
        });
      }

      setMonthlyAttendanceData(monthlyData);
    } catch (error) {
      console.error("Error fetching monthly attendance data:", error);
    } finally {
      setIsLoadingMonthly(false);
    }
  };

  // Calculate student statistics
  const activeStudents = students.filter(s => s.status === "active").length;
  const inactiveStudents = students.filter(s => s.status === "inactive").length;
  const archivedStudents = students.filter(s => s.status === "archived").length;
  const totalStudents = students.length;

  // Calculate teacher statistics
  const activeTeachers = teachers.filter(t => t.status === "active").length;
  const inactiveTeachers = teachers.filter(t => t.status === "inactive").length;
  const leftTeachers = teachers.filter(t => t.status === "left").length;

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Reports & Analytics</h1>
          <p className="text-muted-foreground">
            Comprehensive insights into school statistics
          </p>
        </div>

        {/* Student Statistics Cards */}
        <div className="grid grid-cols-1 md:grid-cols-4 gap-4">
          <Card>
            <CardContent className="p-6">
              <div className="flex items-center justify-between">
                <div>
                  <p className="text-sm font-medium text-muted-foreground">Total Students</p>
                  <p className="text-2xl font-bold">{totalStudents}</p>
                </div>
                <Users className="h-8 w-8 text-blue-600" />
              </div>
            </CardContent>
          </Card>
          
          <Card>
            <CardContent className="p-6">
              <div className="flex items-center justify-between">
                <div>
                  <p className="text-sm font-medium text-muted-foreground">Active Students</p>
                  <p className="text-2xl font-bold text-green-600">{activeStudents}</p>
                </div>
                <UserCheck className="h-8 w-8 text-green-600" />
              </div>
            </CardContent>
          </Card>

          <Card>
            <CardContent className="p-6">
              <div className="flex items-center justify-between">
                <div>
                  <p className="text-sm font-medium text-muted-foreground">Inactive Students</p>
                  <p className="text-2xl font-bold text-yellow-600">{inactiveStudents}</p>
                </div>
                <UserX className="h-8 w-8 text-yellow-600" />
              </div>
            </CardContent>
          </Card>

          <Card>
            <CardContent className="p-6">
              <div className="flex items-center justify-between">
                <div>
                  <p className="text-sm font-medium text-muted-foreground">Archived Students</p>
                  <p className="text-2xl font-bold text-red-600">{archivedStudents}</p>
                </div>
                <ArchiveIcon className="h-8 w-8 text-red-600" />
              </div>
            </CardContent>
          </Card>
        </div>

        {/* Attendance Analysis */}
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          <Card>
            <CardHeader>
              <CardTitle>Daily Attendance Distribution</CardTitle>
              <div className="flex flex-col sm:flex-row gap-4">
                <div className="flex-1">
                  <label className="block text-sm font-medium mb-2">Select Class</label>
                  <Select
                    value={selectedClass}
                    onValueChange={setSelectedClass}
                  >
                    <SelectTrigger>
                      <SelectValue placeholder="Select class" />
                    </SelectTrigger>
                    <SelectContent>
                      {classes.map((cls) => (
                        <SelectItem key={cls.id} value={cls.id}>
                          {cls.level ? `${cls.name} (${cls.level})` : cls.name}
                        </SelectItem>
                      ))}
                    </SelectContent>
                  </Select>
                </div>
                
                <div className="flex-1">
                  <label className="block text-sm font-medium mb-2">Select Date</label>
                  <Popover>
                    <PopoverTrigger asChild>
                      <Button
                        variant="outline"
                        className={cn(
                          "w-full justify-start text-left font-normal",
                          !selectedDate && "text-muted-foreground"
                        )}
                      >
                        <CalendarIcon className="mr-2 h-4 w-4" />
                        {selectedDate ? format(selectedDate, "PPP") : <span>Pick a date</span>}
                      </Button>
                    </PopoverTrigger>
                    <PopoverContent className="w-auto p-0">
                      <Calendar
                        mode="single"
                        selected={selectedDate}
                        onSelect={(date) => date && setSelectedDate(date)}
                        initialFocus
                      />
                    </PopoverContent>
                  </Popover>
                </div>
              </div>
            </CardHeader>
            <CardContent>
              {isLoading ? (
                <div className="flex items-center justify-center h-[300px]">
                  <p className="text-muted-foreground">Loading attendance data...</p>
                </div>
              ) : (
                <ChartContainer
                  title=""
                  type="pie"
                  data={attendanceData}
                />
              )}
            </CardContent>
          </Card>

          <Card>
            <CardHeader>
              <CardTitle>Weekly Attendance Trend</CardTitle>
              <p className="text-sm text-muted-foreground">
                Attendance pattern for the selected week
              </p>
            </CardHeader>
            <CardContent>
              {isLoading ? (
                <div className="flex items-center justify-center h-[300px]">
                  <p className="text-muted-foreground">Loading weekly data...</p>
                </div>
              ) : (
                <ChartContainer
                  title=""
                  type="bar"
                  data={weeklyAttendanceData}
                  dataKeys={{
                    value: 'present',
                    value2: 'absent',
                    value3: 'late',
                    name: 'name'
                  }}
                  legendNames={{
                    value: 'Present',
                    value2: 'Absent',
                    value3: 'Late'
                  }}
                />
              )}
            </CardContent>
          </Card>
        </div>

        {/* Monthly Attendance and Class Distribution */}
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          <Card>
            <CardHeader>
              <CardTitle>Monthly Attendance Rate</CardTitle>
              <p className="text-sm text-muted-foreground">
                Attendance percentage over the last 6 months for {classes.find(c => c.id === selectedClass)?.name || 'selected class'}
              </p>
            </CardHeader>
            <CardContent>
              {isLoadingMonthly ? (
                <div className="flex items-center justify-center h-[300px]">
                  <p className="text-muted-foreground">Loading monthly data...</p>
                </div>
              ) : (
                <ChartContainer
                  title=""
                  type="line"
                  data={monthlyAttendanceData}
                />
              )}
            </CardContent>
          </Card>

          <Card>
            <CardHeader>
              <CardTitle>Students per Class</CardTitle>
              <p className="text-sm text-muted-foreground">
                Distribution of students across classes
              </p>
            </CardHeader>
            <CardContent>
              <ChartContainer
                title=""
                type="bar"
                data={classDistribution}
              />
            </CardContent>
          </Card>
        </div>

        {/* Teacher Statistics */}
        <Card>
          <CardHeader>
            <CardTitle>Staff Overview</CardTitle>
            <p className="text-sm text-muted-foreground">
              Current teaching staff statistics
            </p>
          </CardHeader>
          <CardContent>
            <div className="grid grid-cols-1 md:grid-cols-4 gap-4">
              <div className="p-4 rounded-lg bg-muted">
                <h3 className="text-lg font-semibold mb-2">Total Teachers</h3>
                <p className="text-3xl font-bold">{teachers.length}</p>
              </div>
              <div className="p-4 rounded-lg bg-green-50 dark:bg-green-900/20">
                <h3 className="text-lg font-semibold mb-2 text-green-700 dark:text-green-300">Active Teachers</h3>
                <p className="text-3xl font-bold text-green-600">{activeTeachers}</p>
              </div>
              <div className="p-4 rounded-lg bg-yellow-50 dark:bg-yellow-900/20">
                <h3 className="text-lg font-semibold mb-2 text-yellow-700 dark:text-yellow-300">Inactive Teachers</h3>
                <p className="text-3xl font-bold text-yellow-600">{inactiveTeachers}</p>
              </div>
              <div className="p-4 rounded-lg bg-red-50 dark:bg-red-900/20">
                <h3 className="text-lg font-semibold mb-2 text-red-700 dark:text-red-300">Left Teachers</h3>
                <p className="text-3xl font-bold text-red-600">{leftTeachers}</p>
              </div>
            </div>
          </CardContent>
        </Card>

        {/* Class Statistics */}
        <Card>
          <CardHeader>
            <CardTitle>Class Information</CardTitle>
            <p className="text-sm text-muted-foreground">
              Overview of all classes and their details
            </p>
          </CardHeader>
          <CardContent>
            <div className="overflow-x-auto">
              <table className="w-full">
                <thead>
                  <tr className="border-b">
                    <th className="text-left p-2">Class Name</th>
                    <th className="text-left p-2">Level</th>
                    <th className="text-left p-2">Teacher</th>
                    <th className="text-left p-2">Students</th>
                  </tr>
                </thead>
               <tbody>
  {classes.map((cls) => {
    const studentsInClass = students.filter(s => 
      s.classIds?.includes(cls.id)
    ).length;
    
    return (
      <tr key={cls.id} className="border-b">
        <td className="p-2 font-medium">{cls.name}</td>
        <td className="p-2">{cls.level}</td>
        <td className="p-2">{cls.teacherName || "Unassigned"}</td>
        <td className="p-2">{studentsInClass}</td>
      </tr>
    );
  })}
</tbody>
              </table>
            </div>
          </CardContent>
        </Card>
      </div>
    </DashboardLayout>
  );
}